@@ -1,11 +1,13 @@
 from .._logging import logger
-from ..interface import AbstractDeviceSupportsSet, AbstractDeviceSupportsStatus, StatusDataType
+from ..AbstractDeviceSupportsSet import AbstractDeviceSupportsSet
+from ..AbstractDeviceSupportsStatus import AbstractDeviceSupportsStatus, StatusDataType
 
 
 class DeviceInterface05(AbstractDeviceSupportsStatus, AbstractDeviceSupportsSet):
     """A base class for all the devices implementing the 'device type 05' interface"""
 
     device_type: str = "05"
+    status_message_len_bytes: int = 2
     set_message_len_bytes: int = 3
 
     @staticmethod
