@@ -1,7 +1,8 @@
 from typing import Literal
 
 from .._logging import logger
-from ..interface import AbstractDeviceSupportsSet, AbstractDeviceSupportsStatus, StatusDataType
+from ..AbstractDeviceSupportsSet import AbstractDeviceSupportsSet
+from ..AbstractDeviceSupportsStatus import AbstractDeviceSupportsStatus, StatusDataType
 
 # FIXME: The set methods currently reset some settings while setting the other.
 # For now there is no documented way to obtain the current setting of the
@@ -13,6 +14,7 @@ class DeviceInterface09(AbstractDeviceSupportsStatus, AbstractDeviceSupportsSet)
     """A base class for all the devices implementing the 'device type 09' interface"""
 
     device_type: str = "09"
+    status_message_len_bytes: int = 5
     set_message_len_bytes: int = 3
 
     @staticmethod
