@@ -1,10 +1,11 @@
-from ..interface import AbstractDeviceSupportsStatus, StatusDataType
+from ..AbstractDeviceSupportsStatus import AbstractDeviceSupportsStatus, StatusDataType
 
 
 class DeviceInterface12(AbstractDeviceSupportsStatus):
     """A base class for all the devices implementing the 'device type 12' interface"""
 
     device_type: str = "12"
+    status_message_len_bytes: int = 5
 
     @staticmethod
     def _decode_status(raw_status_data: bytearray) -> StatusDataType:  # TODO: Testing required
