@@ -1,4 +1,4 @@
-from ..interface import AbstractDeviceSupportsStatus, StatusDataType
+from ..AbstractDeviceSupportsStatus import AbstractDeviceSupportsStatus, StatusDataType
 from ..utils import extract_bits
 
 
@@ -6,6 +6,7 @@ class DeviceInterface19(AbstractDeviceSupportsStatus):
     """A base class for all the devices implementing the 'device type 19' interface"""
 
     device_type: str = "19"
+    status_message_len_bytes: int = 5
 
     @staticmethod
     def _decode_status(raw_status_data: bytearray) -> StatusDataType:  # TODO: Testing required
